<?php

namespace TDevAgency\Cms\Controllers;

use Illuminate\Database\Eloquent\Model;
use Illuminate\Foundation\Auth\Access\AuthorizesRequests;
use Illuminate\Foundation\Bus\DispatchesJobs;
use Illuminate\Foundation\Validation\ValidatesRequests;
use Illuminate\Http\Request;
use Illuminate\Routing\Controller as BaseController;
use Illuminate\Support\Facades\App;
use Illuminate\Support\Facades\File;

class Controller extends BaseController
{
    use AuthorizesRequests, DispatchesJobs, ValidatesRequests;


    /**
     * @var Request
     */
    protected $request;

    public function __construct(Request $request)
    {
        $this->request = $request;
    }

    /**
     * Validate the given request with the given rules.
     *
     * @param Request $request
     * @param array $rules
     * @param array $messages
     * @param array $customAttributes
     * @return array
     */
    public function validate(Request $request, array $rules, array $customAttributes = [],
                             array $messages = [])
    {

        $path = TDEV_AGENCY_CMS_ROOT . 'resources' . DIRECTORY_SEPARATOR . 'lang' . DIRECTORY_SEPARATOR . App::getLocale() . DIRECTORY_SEPARATOR . 'validation.php';

        if (File::exists($path)) {
            $defaultMessages = require $path;
            $messages = array_merge($defaultMessages, $messages);
        }

        return $this->getValidationFactory()->make(
            $request->all(), $rules, $messages, $customAttributes
        )->validate();
    }

    protected function setDataToModel(Model $model)
    {
        foreach ($model->getFillable() as $field) {
            if ($this->request->has($field)) {
                $model->setAttribute($field, $this->request->get($field));
            }
        }
    }
}
